==> agr-center-infrastructure-3.0.0-CLOUD-20221226.110131-1-sources.jar: com/tydic/dyc/agr/repository/po/UocAuditOrderPO.java <==
package com.tydic.dyc.agr.repository.po;

import lombok.Data;
import java.io.Serializable;
import java.util.Date;

/**
 * 描述：uoc_audit_order
 * 
 * @author auto_gen
 * @date 2022-10-24 16:03
 **/
@Data
public class UocAuditOrderPO implements Serializable {
	private static final long serialVersionUID =  -6515573466946757310L;

	/**
	 * 审批单id
	 */
	private Long auditOrderId;
	/**
	 * 订单ID
	 */
	private Long orderId;
	/**
	 * 审批单状态
	 */
	private String auditOrderStatus;
	/**
	 * 业务编码
	 */
	private String busiCode;
	/**
	 * 备注
	 */
	private String remark;
	/**
	 * 创建时间
	 */
	private Date createTime;
	private Date createTimeStart;
	private Date createTimeEnd;
	/**
	 * 创建工号
	 */
	private String createOperId;
	/**
	 * 创建人名称
	 */
	private String createOperName;
	/**
	 * 更新时间
	 */
	private Date updateTime;
	private Date updateTimeStart;
	private Date updateTimeEnd;
	/**
	 * 更新工号
	 */
	private String updateOperId;
	/**
	 * 撤单时间
	 */
	private Date cancelTime;
	private Date cancelTimeStart;
	private Date cancelTimeEnd;
	/**
	 * 撤单工号
	 */
	private String cancelOperId;
	/**
	 * 撤单原因
	 */
	private String cancelReason;
	/**
	 * 撤单标志
	 */
	private Integer cancelFlag;
	/**
	 * 竣工时间
	 */
	private Date finishTime;
	private Date finishTimeStart;
	private Date finishTimeEnd;
	/**
	 * 最终审批结果
	 */
	private Integer finalResult;
	/**
	 * 逾期时间
	 */
	private Date expTime;
	private Date expTimeStart;
	private Date expTimeEnd;
	/**
	 * 扩展字段1
	 */
	private String extField1;
	/**
	 * 扩展字段2
	 */
	private String extField2;
	/**
	 * 扩展字段3
	 */
	private String extField3;
	/**
	 * 扩展字段4
	 */
	private String extField4;
	/**
	 * 扩展字段5
	 */
	private String extField5;
	/**
	 * 删除标志
	 */
	private Integer delTag;
	/**
	 * 排序
	 */
	private String orderBy;

}

==> agr-center-infrastructure-3.1.1.0-CLOUD-20230106.111323-2-sources.jar: com/tydic/dyc/agr/repository/po/UocAuditOrderPO.java <==
package com.tydic.dyc.agr.repository.po;

import lombok.Data;
import java.io.Serializable;
import java.util.Date;

/**
 * 描述：uoc_audit_order
 * 
 * @author auto_gen
 * @date 2022-11-22 10:31
 **/
@Data
public class UocAuditOrderPO implements Serializable {
	private static final long serialVersionUID =  4913794016304133120L;

	/**
	 * 审批单id
	 */
	private Long auditOrderId;
	/**
	 * 订单ID
	 */
	private Long orderId;
	/**
	 * 审批单状态
	 */
	private String auditOrderStatus;
	/**
	 * 业务编码
	 */
	private String busiCode;
	/**
	 * 备注
	 */
	private String remark;
	/**
	 * 创建时间
	 */
	private Date createTime;
	private Date createTimeStart;
	private Date createTimeEnd;
	/**
	 * 创建工号
	 */
	private String createOperId;
	/**
	 * 创建人名称
	 */
	private String createOperName;
	/**
	 * 更新时间
	 */
	private Date updateTime;
	private Date updateTimeStart;
	private Date updateTimeEnd;
	/**
	 * 更新工号
	 */
	private String updateOperId;
	/**
	 * 撤单时间
	 */
	private Date cancelTime;
	private Date cancelTimeStart;
	private Date cancelTimeEnd;
	/**
	 * 撤单工号
	 */
	private String cancelOperId;
	/**
	 * 撤单原因
	 */
	private String cancelReason;
	/**
	 * 撤单标志
	 */
	private Integer cancelFlag;
	/**
	 * 竣工时间
	 */
	private Date finishTime;
	private Date finishTimeStart;
	private Date finishTimeEnd;
	/**
	 * 最终审批结果
	 */
	private Integer finalResult;
	/**
	 * 逾期时间
	 */
	private Date expTime;
	private Date expTimeStart;
	private Date expTimeEnd;
	/**
	 * 扩展字段1
	 */
	private String extField1;
	/**
	 * 扩展字段2
	 */
	private String extField2;
	/**
	 * 扩展字段3
	 */
	private String extField3;
	/**
	 * 扩展字段4
	 */
	private String extField4;
	/**
	 * 扩展字段5
	 */
	private String extField5;
	/**
	 * 删除标志
	 */
	private Integer delTag;
	/**
	 * 排序
	 */
	private String orderBy;

}
